/* runsilent.cpp
/
/  (c) 2002-2005 AJ Anderson
/
*/

#include "runsilent.h"
#include "importxml.h"
#include "exportlilypond.h"
#include <string.h>

void
silentconversion (char *file_in, DenemoScore * si)
{
  int result;
  char *file_out;

  if (strcmp (file_in + strlen (file_in) - 7, ".denemo") == 0)
    {
      printf ("\nConverting file %s", file_in);
      result = (int) importXML (file_in, si);
    }

  file_out = "silentconversion.ly";
  exportlilypond ((gchar *) file_out, si, 0, 0);
  printf ("\nWritten to %s\n\n", file_out);
};
